/*
 * TiVo configuration registry
 *
 * Copyright (C) 2001 TiVo Inc. All Rights Reserved.
 */

#include <linux/config.h>

#define kTivoConfigMaxNumSelectors 64

typedef unsigned long TivoConfigSelector;
typedef unsigned long TivoConfigValue;
typedef int TStatus;

#ifdef CONFIG_TCD

void    InitTivoConfig( TivoConfigValue value );
TStatus GetTivoConfig( TivoConfigSelector selector, TivoConfigValue *value );
TStatus SetTivoConfig( TivoConfigSelector selector, TivoConfigValue  value );

#else // stub functions for systems without a config registry

extern inline void    InitTivoConfig( TivoConfigValue value )
{
}

extern inline TStatus GetTivoConfig( TivoConfigSelector selector, TivoConfigValue *value )
{
	return -1;
}

extern inline TStatus SetTivoConfig( TivoConfigSelector selector, TivoConfigValue  value )
{
	return -1;
}

#endif


// use: echo -n BORD | od -t x1

// NOTE: low 8 bits get set to the hardware board rev ID, if present
// upper 24 bits are an enumeration of system config types
enum {
    kTivoConfigBoardID             = 0x424F5244, // 'BORD'
    kTivoConfigBoardIDClassic      = 0x00000100,
    kTivoConfigBoardIDCombo        = 0x00000200,
    kTivoConfigBoardIDBcmUma1      = 0x00000300,
    kTivoConfigBoardIDTL1          = 0x00000400,
    kTivoConfigBoardIDBcmUma2      = 0x00000500,
};

enum {
    kTivoConfigMemSize             = 0x4D454D53, // 'MEMS'
};

enum {
    kTivoConfigI2cType             = 0x49324354, // 'I2CT'
    kTivoConfigI2cTypeSingleMSBus  = 0x00000001, 
    kTivoConfigI2cTypeDualMSBus    = 0x00000002, 
};

enum {
    kTivoConfigContigmemSize       = 0x434d535a, // 'CMSZ'
};

enum {
    kTivoConfigBcmVer              = 0x42434d56, // 'BCMV'
    kTivoConfigBcmVer7020Cx        = 0x00000001, 
    kTivoConfigBcmVer7020RA0       = 0x00000002, 
    kTivoConfigBcmVer7020RBx       = 0x00000003, 
    kTivoConfigBcmVerUnknown       = 0xffffffff, 
};

enum {
    kTivoConfigIdeCap              = 0x49444543, // 'IDEC'
    kTivoConfigIdeCapUdma          = 0x00000001, // bitfield
    kTivoConfigIdeCapAta66         = 0x00000002,
    kTivoConfigIdeCapSG            = 0x00000004,
    kTivoConfigIdeCapScramble      = 0x00000008,
};

enum {
    kTivoConfigFanCheck            = 0x4643484b, // 'FCHK'
    kTivoConfigFanCheckNone        = 0x00000000,
    kTivoConfigFanCheckPresent     = 0x00000001,
};

// This selector holds 2 fixed point 16-bit values:
//  MSB: 8 bit integer part of scalar
//       8 bit fractional part of scalar
//       8 bit integer part of offset
//  LSB: 8 bit fractional part of offset
enum {
    kTivoConfigTempAdj             = 0x544d5041, // 'TMPA'
};

// This selector holds the fan control parameters in units
// of degrees C as reported by the therm driver (ie, after
// adjustment):
// MSB: 8 bit terminal temp
//      8 bit critical temp
//      8 bit log temp
// LSB: 8 bit target temp
enum {
    kTivoConfigFanCtl              = 0x46414e43, // 'FANC'
};
